# oQtopus

<img src="oqtopus/icons/oqtopus-logo.png" alt="logo" width="250"/>

oQtopus : A QGIS module manager that helps you deploy, manage and upgrade your QGIS projects, plugins and associated postgreSQL / PostGIS datamodel implementations.

Installation and upgrade* of your datamodel implementations are managed through the PostgreSQL Upgrade Manager ([PUM](https://github.com/opengisch/pum)).

Read the docs: https://opengisch.github.io/oqtopus/

*upgrade is currently reaching the development phase, this feature will be available soon. Check [here](linktobedefine) to contribute!
